"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.soapFetch = void 0;
/*
 * SPDX-FileCopyrightText: 2024 Zextras <https://www.zextras.com>
 *
 * SPDX-License-Identifier: AGPL-3.0-only
 */
const user_agent_1 = require("./user-agent");
const constants_1 = require("../constants");
const account_1 = require("../store/account");
const network_1 = require("../store/network");
const getAccount = (acc, otherAccount) => {
    if (otherAccount) {
        return {
            by: 'name',
            _content: otherAccount
        };
    }
    if (acc) {
        if (acc.name) {
            return {
                by: 'name',
                _content: acc.name
            };
        }
        if (acc.id) {
            return {
                by: 'id',
                _content: acc.id
            };
        }
    }
    return undefined;
};
const soapFetch = async (api, body, otherAccount, signal) => {
    const { zimbraVersion, account } = account_1.useAccountStore.getState();
    const { notify, session } = network_1.useNetworkStore.getState();
    const res = await fetch(`/service/soap/${api}Request`, {
        signal,
        method: 'POST',
        headers: {
            'Content-Type': 'application/json'
        },
        body: JSON.stringify({
            Body: {
                [`${api}Request`]: body
            },
            Header: {
                context: {
                    _jsns: constants_1.JSNS.all,
                    notify: notify?.[0]?.seq
                        ? {
                            seq: notify?.[0]?.seq
                        }
                        : undefined,
                    session: session ?? {},
                    account: getAccount(account, otherAccount),
                    userAgent: {
                        name: user_agent_1.userAgent,
                        version: zimbraVersion
                    }
                }
            }
        })
    });
    return res.json();
};
exports.soapFetch = soapFetch;
//# sourceMappingURL=fetch-utils.js.map