"use strict";
/*
 * SPDX-FileCopyrightText: 2022 Zextras <https://www.zextras.com>
 *
 * SPDX-License-Identifier: AGPL-3.0-only
 */
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.normalizeBoardView = exports.normalizeSecondaryAccessoryView = exports.normalizePrimaryAccessoryView = exports.normalizeUtilityView = exports.normalizeSettingsView = exports.normalizeRoute = exports.normalizeBadgeInfo = exports.normalizeApp = void 0;
const react_1 = __importDefault(require("react"));
const lodash_1 = require("lodash");
const normalizeApp = (app) => ({
    commit: app.commit ?? '',
    description: app.description ?? 'A carbonio Module',
    // eslint-disable-next-line camelcase
    js_entrypoint: app.js_entrypoint ?? '',
    name: app.name ?? 'module',
    priority: app.priority ?? 99,
    version: app.version ?? '',
    type: app.type ?? 'carbonio',
    attrKey: app.attrKey,
    icon: app.icon ?? 'Cube',
    display: app.display ?? 'Module',
    sentryDsn: app.sentryDsn
});
exports.normalizeApp = normalizeApp;
const FallbackView = () => react_1.default.createElement("p", null, "Missing Component");
const normalizeBadgeInfo = (badge) => ({
    ...badge,
    show: badge.show ?? false,
    count: badge.count ?? 0,
    showCount: badge.showCount ?? false,
    color: badge.color ?? 'primary'
});
exports.normalizeBadgeInfo = normalizeBadgeInfo;
const normalizeRoute = (data, app) => {
    const route = (0, lodash_1.trim)(data.route ?? app.name, '/');
    return {
        app: app.name,
        route,
        id: data.id ?? route,
        badge: (0, exports.normalizeBadgeInfo)(data?.badge ?? {}),
        position: data?.position ?? app.priority,
        visible: data?.visible ?? true,
        label: data?.label ?? '',
        primaryBar: data.primaryBar ?? app.icon ?? 'CubeOutline',
        secondaryBar: data.secondaryBar,
        appView: data.appView ?? FallbackView,
        focusMode: data.focusMode
    };
};
exports.normalizeRoute = normalizeRoute;
const normalizeSettingsView = (data, app) => {
    const route = (0, lodash_1.trim)(data.route ?? app.name, '/');
    return {
        app: app.name,
        route,
        id: data?.id ?? route,
        component: data?.component ?? FallbackView,
        label: data.label ?? app.display,
        icon: data.icon ?? app.icon,
        position: data.position ?? app.priority ?? 99,
        subSections: data.subSections ?? []
    };
};
exports.normalizeSettingsView = normalizeSettingsView;
const normalizeUtilityView = (data, app) => ({
    app: app.name,
    id: data?.id ?? app.name,
    whitelistRoutes: data?.whitelistRoutes,
    blacklistRoutes: data?.blacklistRoutes,
    component: data?.component ?? FallbackView,
    button: data?.button ?? 'Cube',
    position: data?.position ?? app.priority,
    label: data?.label ?? app.display,
    panelVisible: data?.panelVisible ?? true
});
exports.normalizeUtilityView = normalizeUtilityView;
const normalizePrimaryAccessoryView = (data, app) => ({
    app: app.name,
    onClick: data?.onClick,
    label: data?.label ?? app.display,
    position: data?.position ?? app.priority,
    whitelistRoutes: data?.whitelistRoutes,
    blacklistRoutes: data?.blacklistRoutes,
    id: data?.id ?? app.name,
    component: data?.component ?? FallbackView
});
exports.normalizePrimaryAccessoryView = normalizePrimaryAccessoryView;
const normalizeSecondaryAccessoryView = (data, app) => ({
    app: app.name,
    position: data?.position ?? app.priority,
    whitelistRoutes: data?.whitelistRoutes,
    blacklistRoutes: data?.blacklistRoutes,
    id: data?.id ?? app.name,
    component: data?.component ?? FallbackView
});
exports.normalizeSecondaryAccessoryView = normalizeSecondaryAccessoryView;
const normalizeBoardView = (data, app) => ({
    app: app.name,
    id: data.id,
    component: data.component
});
exports.normalizeBoardView = normalizeBoardView;
//# sourceMappingURL=utils.js.map