"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.buildIntegrationComponent = buildIntegrationComponent;
exports.buildIntegrationFunction = buildIntegrationFunction;
exports.buildIntegrationActions = buildIntegrationActions;
exports.buildIntegrationAction = buildIntegrationAction;
/*
 * SPDX-FileCopyrightText: 2024 Zextras <https://www.zextras.com>
 *
 * SPDX-License-Identifier: AGPL-3.0-only
 */
const react_1 = __importDefault(require("react"));
const lodash_1 = require("lodash");
const app_context_provider_1 = require("../../boot/app/app-context-provider");
function buildIntegrationComponent(integration) {
    if (integration) {
        const IntegrationComponent = (props) => (react_1.default.createElement(app_context_provider_1.AppContextProvider, { pkg: integration.app },
            react_1.default.createElement(integration.Item, { ...props })));
        return [IntegrationComponent, true];
    }
    return [(() => null), false];
}
function buildIntegrationFunction(integration) {
    return integration
        ? [integration, true]
        : [(() => undefined), false];
}
function buildIntegrationActions(integration, context) {
    return (0, lodash_1.compact)((0, lodash_1.map)(integration, (actionFactory) => {
        try {
            return actionFactory(context);
        }
        catch (e) {
            // eslint-disable-next-line no-console
            console.error(e);
            return undefined;
        }
    }));
}
function buildIntegrationAction(integration, target) {
    try {
        if (!integration) {
            return [undefined, false];
        }
        return [integration(target), true];
    }
    catch (e) {
        return [undefined, false];
    }
}
//# sourceMappingURL=utils.js.map